# msdss-base-database

[![pypi package](https://badge.fury.io/py/msdss-base-database.svg)](https://pypi.org/project/msdss-base-database)
[![Github](https://img.shields.io/badge/Github-rrwen%2Fmsdss--base--database-brightgreen?logo=Github)](https://github.com/rrwen/msdss-base-database)
[![downloads](https://img.shields.io/pypi/dm/msdss-base-database.svg)](https://pypistats.org/packages/msdss-base-database)
[![GitHub stars](https://img.shields.io/github/stars/rrwen/msdss-base-database.svg)](https://github.com/rrwen/msdss-base-database/stargazers)
[![GitHub](https://img.shields.io/github/license/rrwen/msdss-base-database.svg)](https://github.com/rrwen/msdss-base-database/blob/main/LICENSE)
  
Base database for the Modular Spatial Decision Support Systems (MSDSS) framework.

* [Documentation](https://rrwen.github.io/msdss-base-database/)
* [Developer Notes](https://github.com/rrwen/msdss-base-database/blob/main/DEVELOPER.md)

## Contact

Richard Wen rrwen.dev@gmail.com
